@@ -1,31 +1,3 @@
-## Tools for manipulation of text count matrices ##
-stm2dg <- function(x, ...){
-  sparseMatrix(i=x$i, j=x$j, x=x$v,
-        dims=dim(x),dimnames=dimnames(x), ...) }
-
-## correlation 
-corr <- function(x, y){
-  if(inherits(x, "simple_triplet_matrix")) x <- stm2dg(x)
-  if(!inherits(x, "dgCMatrix")){ return(cor(x,y) ) }
-
-  n <- nrow(x)
-  v <- t(scale(y))
-  
-  r <- tcrossprod(t(x)/sdev(x), v)/(n-1)
-  dimnames(r) <- list(dimnames(x)[[2]], dimnames(y)[[2]])
-  return( r ) 
-}
-  
-## column standard deviation 
-sdev <- function(x){
-  if(is.null(dim(x))) return(sd(x))
-  if(inherits(x, "simple_triplet_matrix")) x <- stm2dg(x)
-  if(!inherits(x, "dgCMatrix")){ return(apply(as.matrix(x),2,sd)) }
-  n <- nrow(x)
-  s <- sqrt(colSums(x^2)/(n-1) - colSums(x)^2/(n^2 - n)) 
-  names(s) <- colnames(s)
-  return(s)  }
-
 ## minimalist partial least squares
 pls <- function(x, y, K=1, scale=TRUE, verb=TRUE){
 
@@ -54,7 +26,7 @@ pls <- function(x, y, K=1, scale=TRUE, verb=TRUE){
     
     ## project the fitted direction
     if(inherits(x, "dgCMatrix")){
-      z[,k] <- as.matrix(tcrossprod(x, t(phi[,k])))
+      z[,k] <- as.matrix(x%*%phi[,k])
     } else { z[,k] <- x%*%phi[,k] }
 
     ## ortho-normalize
@@ -124,7 +96,7 @@ predict.pls <- function(object, newdata, type="response", ...)
   if(inherits(newdata, "simple_triplet_matrix")) 
     newdata <- stm2dg(newdata)
   if(inherits(newdata,"dgCmatrix"))
-    z <- tcrossprod(newdata, t(object$loadings))
+    z <- newdata%*%object$loadings
   else z <- as.matrix(newdata)%*%object$loadings
   
   z <- t(t(z) - object$shift)
